LLMUnknownException class final

上記いずれにも分類できない不明なエラー。

Inheritance

Constructors

LLMUnknownException(String message, {int? statusCode, String? provider, String? code, Object? raw})
const

Properties

code String?
プロバイダー固有のエラーコード/タイプ文字列(取得できた場合)。
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
人間可読のエラーメッセージ。
finalinherited
provider String?
発生元プロバイダー名('openai' / 'claude' / 'gemini' など)。
finalinherited
raw Object?
元の例外・レスポンスボディなど(デバッグ用)。
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
HTTP ステータスコード(取得できた場合)。
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited