LLMCompletionResponse class
LLM からのチャット補完レスポンス。
Constructors
- LLMCompletionResponse({required LLMContent content, required LLMUsage usage, required LLMFinishReason finishReason, String? model, String? id})
-
const
Properties
- content → LLMContent
-
応答メッセージ(テキスト・画像・音声・ツール呼び出しなどを含む)。
final
- finishReason → LLMFinishReason
-
生成が終了した理由(正規化済み)。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
レスポンス ID(取得できた場合)。
final
- inputTokens → int
-
入力トークン数(後方互換)。
no setter
- model → String?
-
実際に使われたモデル名(取得できた場合)。
final
- outputTokens → int
-
出力トークン数(後方互換)。
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
応答本文のテキスト。
no setter
-
toolCalls
→ List<
LLMToolCallPart> -
ツール呼び出しの一覧(あれば)。
no setter
- usage → LLMUsage
-
トークン使用量。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited