LLMStreamChunk class
ストリーミング応答の 1 チャンク。
途中のチャンクは delta(本文テキストの増分)や reasoningDelta (thinking テキストの増分)を運び、最終チャンクは finishReason と parts(確定した全パーツ)・usage を運ぶ。
Constructors
-
LLMStreamChunk({String delta = '', String reasoningDelta = '', List<
LLMContentPart> ? parts, LLMFinishReason? finishReason, LLMUsage? usage}) -
const
Properties
- delta → String
-
直前からの増分テキスト。
final
- finishReason → LLMFinishReason?
-
完了理由(最終チャンクのみ)。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDone → bool
-
このチャンクで生成が完了したか。
no setter
-
parts
→ List<
LLMContentPart> ? -
確定したパーツ(完了時などに付与される)。
final
- reasoningDelta → String
-
直前からの推論(thinking / reasoning)テキストの増分。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usage → LLMUsage?
-
トークン使用量(取得できた場合、通常は最終チャンク)。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited